@@ -115,13 +115,13 @@ CDesktop::CDesktop()
     nextButton = new QPushButton(this);
     //Transparent button
     nextButton->setFlat(true);
-    nextButton->setUpdatesEnabled(false);
+    //nextButton->setUpdatesEnabled(false);
     connect(nextButton, SIGNAL(clicked(bool)), this, SLOT(slotClickedNext(bool)));
 
     previousButton = new QPushButton(this);
     //Transparent button
     previousButton->setFlat(true);
-    previousButton->setUpdatesEnabled(false);
+    //previousButton->setUpdatesEnabled(false);
     connect(previousButton, SIGNAL(clicked(bool)), this, SLOT(slotClickedPrevious(bool)));
 
 }
