@@ -32,9 +32,9 @@ CDlgSetup::CDlgSetup()
 {
     setupUi(this);
     // init plug values
-    cMafw->setChecked(CMafwMeta::self().getEnable() );
-    cRTCom->setChecked(CRTCom::self().getEnable() );
-    cSms->setChecked(CSms::self().getEnable() );
+    cMafw->setChecked(CMafwMeta::self().getState() );
+    cRTCom->setChecked(CRTCom::self().getState() );
+    cSms->setChecked(CSms::self().getState() );
 
     // connect buttons
     connect(bMain, SIGNAL(clicked()), this, SLOT(slotMainSetup()));
