@@ -36,7 +36,7 @@ CRTCom::CRTCom(QObject * parent)
     format = cfg.value("display/RTCom/format", format).toString();
     timeout = cfg.value("display/RTCom/timeout", timeout).toInt();
     state = cfg.value("main/RTCom", state).toBool();
-    setConnect(state);
+    connect = false;
 }
 
 
@@ -71,14 +71,19 @@ int CRTCom::getTimeout()
 void CRTCom::setEnable(bool value)
 {
     if (value) {
-       state = QDBusConnection::systemBus().connect( 0, RTCOM_CSD_PATH, RTCOM_CSD_IF,  "Coming", this, SLOT(slotComingChanged(QDBusObjectPath,QString)));
+       QDBusConnection::systemBus().connect( 0, RTCOM_CSD_PATH, RTCOM_CSD_IF,  "Coming", this, SLOT(slotComingChanged(QDBusObjectPath,QString)));
     } else {
        QDBusConnection::systemBus().disconnect( 0, RTCOM_CSD_PATH, RTCOM_CSD_IF,  "Coming", this, SLOT(slotComingChanged(QDBusObjectPath,QString)));
-       state = value;
     }
+    state = value;
 }
 
 bool CRTCom::getEnable()
+{
+    return state && connect;
+}
+
+bool CRTCom::getState()
 {
     return state;
 }
@@ -97,13 +102,13 @@ void CRTCom::slotCallStatus(uint state, uint ukn1, uint ukn2)
 {
     if (state == 10) 
     {
-        callText.prepend(tr("Ringing ") );
-        sendText(callText);
+        //callText.prepend(tr("Ringing ") );
+        sendText(tr("Ringing ") + callText);
     }
     if (state == 0) 
     {
-        callText.prepend(tr("Ended ") );
-        sendText(callText);
+        //callText.prepend( );
+        sendText(tr("Ended ")+callText);
     }
 }
 
@@ -120,4 +125,5 @@ void CRTCom::setConnect(int value)
     } else {
         QDBusConnection::systemBus().disconnect( 0, RTCOM_CSD_PATH, RTCOM_CSD_IF,  "Coming", this, SLOT(slotComingChanged(QDBusObjectPath,QString)));
     }
+    connect = value;
 }
