@@ -41,6 +41,7 @@ class CRTCom : public IRdsText
 	// state plug on or off
         void    setEnable(bool value);
 	bool getEnable();
+        bool getState();
 	// connect plug
 	void setConnect(int value);
 
@@ -62,6 +63,8 @@ class CRTCom : public IRdsText
 	int timeout;
 	// Pluig status
 	bool state;
+        // Tx connect state
+        bool connect;
 
     private slots:
 	void slotComingChanged(QDBusObjectPath objectPath, QString caller);
