@@ -75,7 +75,7 @@ int main(int argc, char **argv)
                      Qt::HANDLE(visual), Qt::HANDLE(colormap));
 
     CDesktop w;
-    w.resize(325,174 );
+    //w.resize(330,260 );
     w.show();
 
     return app.exec(); 
